Index: chrome/browser/ui/browser_window.h |
diff --git a/chrome/browser/ui/browser_window.h b/chrome/browser/ui/browser_window.h |
index 9394cb955740e52edd8b9ff9bb09391c09e49ab8..25ded9161b5470971f8520c6f4d309c15f777d7d 100644 |
--- a/chrome/browser/ui/browser_window.h |
+++ b/chrome/browser/ui/browser_window.h |
@@ -294,11 +294,11 @@ class BrowserWindow : public ui::BaseWindow { |
// that it's time to redraw everything. |
virtual void UserChangedTheme() = 0; |
// Shows the website settings using the specified information. |virtual_url| |
// is the virtual url of the page/frame the info applies to, |ssl| is the SSL |
// information for that page/frame. If |show_history| is true, a section |
// showing how many times that URL has been visited is added to the page info. |
- virtual void ShowWebsiteSettings( |
+ virtual void ShowPageInfo( |
Profile* profile, |
content::WebContents* web_contents, |
const GURL& virtual_url, |
@@ -294,11 +294,11 @@ class BrowserWindow : public ui::BaseWindow { |
// that it's time to redraw everything. |
virtual void UserChangedTheme() = 0; |
- // Shows the website settings using the specified information. |virtual_url| |
+ // Shows Page Info using the specified information. |virtual_url| |
// is the virtual url of the page/frame the info applies to, |ssl| is the SSL |
// information for that page/frame. If |show_history| is true, a section |